@@ -1,13 +1,16 @@
+from abc import ABCMeta, abstractmethod
 from typing import Tuple, Any
 
 from .IAbortable import IAbortable
 
 
-class IFlatField(IAbortable):
+class IFlatField(IAbortable, metaclass=ABCMeta):
     """The module performs flat-fielding."""
-    __module__ = 'pyobs.interfaces'
 
-    def flat_field(self, count: int = 20, **kwargs: Any) -> Tuple[int, float]:
+    __module__ = "pyobs.interfaces"
+
+    @abstractmethod
+    async def flat_field(self, count: int = 20, **kwargs: Any) -> Tuple[int, float]:
         """Do a series of flat fields.
 
         Args:
@@ -16,7 +19,7 @@ class IFlatField(IAbortable):
         Returns:
             Number of images actually taken and total exposure time in ms
         """
-        raise NotImplementedError
+        ...
 
 
-__all__ = ['IFlatField']
+__all__ = ["IFlatField"]
