@@ -1,8 +1,7 @@
 import logging
 from typing import Union, Dict, Any
 
-from pyobs.interfaces import IRunnable
-from pyobs.interfaces.proxies import ITelescopeProxy
+from pyobs.interfaces import IRunnable, ITelescope
 from pyobs.modules import Module
 from pyobs.object import get_object
 from pyobs.modules import timeout
@@ -13,10 +12,12 @@ log = logging.getLogger(__name__)
 
 class FlatFieldPointing(Module, IRunnable):
     """Module for pointing a telescope."""
-    __module__ = 'pyobs.modules.flatfield'
 
-    def __init__(self, telescope: Union[str, ITelescopeProxy],
-                 pointing: Union[Dict[str, Any], SkyFlatsBasePointing], **kwargs: Any):
+    __module__ = "pyobs.modules.flatfield"
+
+    def __init__(
+        self, telescope: Union[str, ITelescope], pointing: Union[Dict[str, Any], SkyFlatsBasePointing], **kwargs: Any
+    ):
         """Initialize a new flat field pointing.
 
         Args:
@@ -30,23 +31,23 @@ class FlatFieldPointing(Module, IRunnable):
         self._pointing = pointing
 
     @timeout(60)
-    def run(self, **kwargs: Any) -> None:
+    async def run(self, **kwargs: Any) -> None:
         """Move telescope to pointing."""
 
         # get telescope
-        log.info('Getting proxy for telescope...')
-        telescope: ITelescopeProxy = self.proxy(self._telescope, ITelescopeProxy)
+        log.info("Getting proxy for telescope...")
+        telescope = await self.proxy(self._telescope, ITelescope)
 
         # pointing
         pointing = get_object(self._pointing, SkyFlatsBasePointing, observer=self.observer)
 
         # point
-        pointing(telescope).wait()
-        log.info('Finished pointing telescope.')
+        await pointing(telescope)
+        log.info("Finished pointing telescope.")
 
     def abort(self, **kwargs: Any) -> None:
         """Abort current actions."""
         pass
 
 
-__all__ = ['FlatFieldPointing']
+__all__ = ["FlatFieldPointing"]
