@@ -4,7 +4,6 @@ import threading
 import numpy as np
 from numpy.typing import NDArray
 
-from pyobs.comm import RemoteException
 from pyobs.interfaces import IAutoFocus
 from pyobs.events import FocusFoundEvent
 from pyobs.interfaces import IExposureTime, IImageType, IFocuser, IFilters, IImageGrabber
@@ -13,6 +12,7 @@ from pyobs.mixins import CameraSettingsMixin
 from pyobs.modules import timeout, Module
 from pyobs.utils.enums import ImageType
 from pyobs.utils.focusseries import FocusSeries
+from pyobs.utils import exceptions as exc
 
 log = logging.getLogger(__name__)
 
@@ -26,7 +26,7 @@ class AutoFocusSeries(Module, CameraSettingsMixin, IAutoFocus):
         self,
         focuser: Union[str, IFocuser],
         camera: Union[str, IImageGrabber],
-        series: FocusSeries,
+        series: Union[Dict[str, Any], FocusSeries],
         offset: bool = False,
         filters: Optional[Union[str, IFilters]] = None,
         filter_name: Optional[str] = None,
@@ -57,6 +57,16 @@ class AutoFocusSeries(Module, CameraSettingsMixin, IAutoFocus):
         # init camera settings mixin
         CameraSettingsMixin.__init__(self, filters=filters, filter_name=filter_name, binning=binning, **kwargs)
 
+        # register exceptions
+        if isinstance(camera, str):
+            exc.register_exception(
+                exc.RemoteError, 3, timespan=600, module=camera, callback=self._default_remote_error_callback
+            )
+        if isinstance(focuser, str):
+            exc.register_exception(
+                exc.RemoteError, 3, timespan=600, module=focuser, callback=self._default_remote_error_callback
+            )
+
     async def open(self) -> None:
         """Open module"""
         await Module.open(self)
@@ -119,7 +129,7 @@ class AutoFocusSeries(Module, CameraSettingsMixin, IAutoFocus):
             else:
                 guess = await focuser.get_focus()
                 log.info("Using current focus of %.2fmm as initial guess.", guess)
-        except RemoteException:
+        except exc.RemoteError:
             raise ValueError("Could not fetch current focus value.")
 
         # define array of focus values to iterate
@@ -145,7 +155,7 @@ class AutoFocusSeries(Module, CameraSettingsMixin, IAutoFocus):
                 else:
                     await focuser.set_focus(float(foc))
 
-            except RemoteException:
+            except exc.RemoteError:
                 raise ValueError("Could not set new focus value.")
 
             # do exposure
@@ -158,7 +168,7 @@ class AutoFocusSeries(Module, CameraSettingsMixin, IAutoFocus):
                 if isinstance(camera, IImageType):
                     await camera.set_image_type(ImageType.FOCUS)
                 filename = await camera.grab_image()
-            except RemoteException:
+            except exc.RemoteError:
                 log.error("Could not take image.")
                 continue
 
